@@ -120,8 +120,31 @@ class te_services:
         })
         return projectData
 
-    def getPerformanceProjectData(self, tableName, count=1, consumed=True,
-                                  queryJSON=None, projectName=None, isE2E=False):
+    def getProjectDataCount(self, tableName, queryJSON=None, projectName=None, isE2E=False):
+        _projectName = projectName if projectName is not None else self.te_config_json[
+            "Project"]
+        requestUR = self.te_config_json["Server"] + "/" + \
+            self.te_constant["ServerAPI"]["PROJECT_DATA"] + \
+            "/" + _projectName + \
+            "/" + tableName + \
+            "/counter"
+        if isE2E:
+            if queryJSON is None:
+                queryJSON = {}
+            queryJSON["_buildid"] = self.te_config_json["BuildID"]
+        if queryJSON is not None:
+            qString = urlencode(queryJSON)
+            requestUR += "?"+qString
+        result = requests.get(requestUR, headers=self.headers)
+        projectDataCount = json.loads(result.text)
+        self.addE2EData({
+            "name": self.te_constant["E2EDataType"].get("INTPUT"),
+            "type": self.te_constant["E2ETableType"].get("PROJECT"),
+            "description": projectDataCount
+        })
+        return projectDataCount
+
+    def getPerformanceProjectData(self, tableName, count=1, consumed=True, queryJSON=None, projectName=None, isE2E=False):
         _projectName = projectName if projectName is not None else self.te_config_json[
             "Project"]
         requestUR = self.te_config_json["Server"] + "/" + \
@@ -169,8 +192,31 @@ class te_services:
         })
         return masterData
 
-    def getPerformanceMasterData(self, tableName, count=1, consumed=True,
-                                 queryJSON=None, projectName=None, isE2E=False):
+    def getMasterDataCount(self, tableName, queryJSON=None, projectName=None, isE2E=False):
+        _projectName = projectName if projectName is not None else self.te_config_json[
+            "Project"]
+        requestUR = self.te_config_json["Server"] + "/" + \
+            self.te_constant["ServerAPI"]["MASTER_DATA"] + \
+            "/" + _projectName + \
+            "/" + tableName + \
+            "/counter"
+        if isE2E:
+            if queryJSON is None:
+                queryJSON = {}
+            queryJSON["_buildid"] = self.te_config_json["BuildID"]
+        if queryJSON is not None:
+            qString = urlencode(queryJSON)
+            requestUR += "?"+qString
+        result = requests.get(requestUR, headers=self.headers)
+        masterDataCount = json.loads(result.text)
+        self.addE2EData({
+            "name": self.te_constant["E2EDataType"].get("INTPUT"),
+            "type": self.te_constant["E2ETableType"].get("PROJECT"),
+            "description": masterDataCount
+        })
+        return masterDataCount
+
+    def getPerformanceMasterData(self, tableName, count=1, consumed=True, queryJSON=None, projectName=None, isE2E=False):
         _projectName = projectName if projectName is not None else self.te_config_json[
             "Project"]
         requestUR = self.te_config_json["Server"]+"/" + \
@@ -286,6 +332,21 @@ class te_services:
         caseData = json.loads(result.text)
         return caseData
 
+    def getProjectSecretData(self, name: str, projectName=None):
+        _projectName = projectName if projectName is not None else self.te_config_json[
+            "Project"]
+        requestUR = self.te_config_json["Server"]+"/" + \
+            self.te_constant["ServerAPI"]["CASE_DATA"] + \
+            "/"+_projectName + "/secret/" + name
+        result = requests.get(requestUR, headers=self.headers)
+        projectSecretDataResponse = json.loads(result.text)
+        if projectSecretDataResponse['message'] == 'Success':
+            projectSecretDataValue = projectSecretDataResponse['body']['result']['value']
+            return projectSecretDataValue
+        else:
+            print(projectSecretDataResponse['err'])
+            return None
+
     def deleteProjectData(self, tableName, id, projectName=None):
         _projectName = projectName if projectName is not None else self.te_config_json[
             "Project"]
@@ -326,7 +387,7 @@ class te_services:
         reportFileName = self.te_config_json.get("Report").get("File")
         reportFolderPath = self.te_config_json.get("Report").get("Path")
         imagePath = self.te_config_json.get("Report").get("ImagePath")
-        reportJSONList=[]
+        reportJSONList = []
         if self.te_config_json["Agent"] == "NOSE":
             if reportFileName == None or reportFileName == "":
                 if os.path.exists(reportFolderPath):
@@ -408,8 +469,9 @@ class te_services:
             # ==todo: clean data, before the script stateble
         # upload report
         for reportObjIndex in reportJSONList:
-            bodyJSON["report"]=reportObjIndex
-            result = requests.post(requestUR, json=bodyJSON, headers=self.headers)
+            bodyJSON["report"] = reportObjIndex
+            result = requests.post(
+                requestUR, json=bodyJSON, headers=self.headers)
         reportData = json.loads(result.text)
         return reportData
 
